/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleIdentityPlatformConfigConfig extends cdktf.TerraformMetaArguments {
    /**
    * List of domains authorized for OAuth redirects.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.78.0/docs/resources/google_identity_platform_config#authorized_domains GoogleIdentityPlatformConfig#authorized_domains}
    */
    readonly authorizedDomains?: string[];
    /**
    * Whether anonymous users will be auto-deleted after a period of 30 days
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.78.0/docs/resources/google_identity_platform_config#autodelete_anonymous_users GoogleIdentityPlatformConfig#autodelete_anonymous_users}
    */
    readonly autodeleteAnonymousUsers?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.78.0/docs/resources/google_identity_platform_config#id GoogleIdentityPlatformConfig#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.78.0/docs/resources/google_identity_platform_config#project GoogleIdentityPlatformConfig#project}
    */
    readonly project?: string;
    /**
    * blocking_functions block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.78.0/docs/resources/google_identity_platform_config#blocking_functions GoogleIdentityPlatformConfig#blocking_functions}
    */
    readonly blockingFunctions?: GoogleIdentityPlatformConfigBlockingFunctions;
    /**
    * quota block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.78.0/docs/resources/google_identity_platform_config#quota GoogleIdentityPlatformConfig#quota}
    */
    readonly quota?: GoogleIdentityPlatformConfigQuota;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.78.0/docs/resources/google_identity_platform_config#timeouts GoogleIdentityPlatformConfig#timeouts}
    */
    readonly timeouts?: GoogleIdentityPlatformConfigTimeouts;
}
export interface GoogleIdentityPlatformConfigBlockingFunctionsForwardInboundCredentials {
    /**
    * Whether to pass the user's OAuth identity provider's access token.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.78.0/docs/resources/google_identity_platform_config#access_token GoogleIdentityPlatformConfig#access_token}
    */
    readonly accessToken?: boolean | cdktf.IResolvable;
    /**
    * Whether to pass the user's OIDC identity provider's ID token.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.78.0/docs/resources/google_identity_platform_config#id_token GoogleIdentityPlatformConfig#id_token}
    */
    readonly idToken?: boolean | cdktf.IResolvable;
    /**
    * Whether to pass the user's OAuth identity provider's refresh token.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.78.0/docs/resources/google_identity_platform_config#refresh_token GoogleIdentityPlatformConfig#refresh_token}
    */
    readonly refreshToken?: boolean | cdktf.IResolvable;
}
export declare function googleIdentityPlatformConfigBlockingFunctionsForwardInboundCredentialsToTerraform(struct?: GoogleIdentityPlatformConfigBlockingFunctionsForwardInboundCredentialsOutputReference | GoogleIdentityPlatformConfigBlockingFunctionsForwardInboundCredentials): any;
export declare class GoogleIdentityPlatformConfigBlockingFunctionsForwardInboundCredentialsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleIdentityPlatformConfigBlockingFunctionsForwardInboundCredentials | undefined;
    set internalValue(value: GoogleIdentityPlatformConfigBlockingFunctionsForwardInboundCredentials | undefined);
    private _accessToken?;
    get accessToken(): boolean | cdktf.IResolvable;
    set accessToken(value: boolean | cdktf.IResolvable);
    resetAccessToken(): void;
    get accessTokenInput(): boolean | cdktf.IResolvable | undefined;
    private _idToken?;
    get idToken(): boolean | cdktf.IResolvable;
    set idToken(value: boolean | cdktf.IResolvable);
    resetIdToken(): void;
    get idTokenInput(): boolean | cdktf.IResolvable | undefined;
    private _refreshToken?;
    get refreshToken(): boolean | cdktf.IResolvable;
    set refreshToken(value: boolean | cdktf.IResolvable);
    resetRefreshToken(): void;
    get refreshTokenInput(): boolean | cdktf.IResolvable | undefined;
}
export interface GoogleIdentityPlatformConfigBlockingFunctionsTriggers {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.78.0/docs/resources/google_identity_platform_config#event_type GoogleIdentityPlatformConfig#event_type}
    */
    readonly eventType: string;
    /**
    * HTTP URI trigger for the Cloud Function.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.78.0/docs/resources/google_identity_platform_config#function_uri GoogleIdentityPlatformConfig#function_uri}
    */
    readonly functionUri: string;
}
export declare function googleIdentityPlatformConfigBlockingFunctionsTriggersToTerraform(struct?: GoogleIdentityPlatformConfigBlockingFunctionsTriggers | cdktf.IResolvable): any;
export declare class GoogleIdentityPlatformConfigBlockingFunctionsTriggersOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleIdentityPlatformConfigBlockingFunctionsTriggers | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleIdentityPlatformConfigBlockingFunctionsTriggers | cdktf.IResolvable | undefined);
    private _eventType?;
    get eventType(): string;
    set eventType(value: string);
    get eventTypeInput(): string | undefined;
    private _functionUri?;
    get functionUri(): string;
    set functionUri(value: string);
    get functionUriInput(): string | undefined;
    get updateTime(): string;
}
export declare class GoogleIdentityPlatformConfigBlockingFunctionsTriggersList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleIdentityPlatformConfigBlockingFunctionsTriggers[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleIdentityPlatformConfigBlockingFunctionsTriggersOutputReference;
}
export interface GoogleIdentityPlatformConfigBlockingFunctions {
    /**
    * forward_inbound_credentials block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.78.0/docs/resources/google_identity_platform_config#forward_inbound_credentials GoogleIdentityPlatformConfig#forward_inbound_credentials}
    */
    readonly forwardInboundCredentials?: GoogleIdentityPlatformConfigBlockingFunctionsForwardInboundCredentials;
    /**
    * triggers block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.78.0/docs/resources/google_identity_platform_config#triggers GoogleIdentityPlatformConfig#triggers}
    */
    readonly triggers: GoogleIdentityPlatformConfigBlockingFunctionsTriggers[] | cdktf.IResolvable;
}
export declare function googleIdentityPlatformConfigBlockingFunctionsToTerraform(struct?: GoogleIdentityPlatformConfigBlockingFunctionsOutputReference | GoogleIdentityPlatformConfigBlockingFunctions): any;
export declare class GoogleIdentityPlatformConfigBlockingFunctionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleIdentityPlatformConfigBlockingFunctions | undefined;
    set internalValue(value: GoogleIdentityPlatformConfigBlockingFunctions | undefined);
    private _forwardInboundCredentials;
    get forwardInboundCredentials(): GoogleIdentityPlatformConfigBlockingFunctionsForwardInboundCredentialsOutputReference;
    putForwardInboundCredentials(value: GoogleIdentityPlatformConfigBlockingFunctionsForwardInboundCredentials): void;
    resetForwardInboundCredentials(): void;
    get forwardInboundCredentialsInput(): GoogleIdentityPlatformConfigBlockingFunctionsForwardInboundCredentials | undefined;
    private _triggers;
    get triggers(): GoogleIdentityPlatformConfigBlockingFunctionsTriggersList;
    putTriggers(value: GoogleIdentityPlatformConfigBlockingFunctionsTriggers[] | cdktf.IResolvable): void;
    get triggersInput(): cdktf.IResolvable | GoogleIdentityPlatformConfigBlockingFunctionsTriggers[] | undefined;
}
export interface GoogleIdentityPlatformConfigQuotaSignUpQuotaConfig {
    /**
    * A sign up APIs quota that customers can override temporarily.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.78.0/docs/resources/google_identity_platform_config#quota GoogleIdentityPlatformConfig#quota}
    */
    readonly quota?: number;
    /**
    * How long this quota will be active for. It is measurred in seconds, e.g., Example: "9.615s".
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.78.0/docs/resources/google_identity_platform_config#quota_duration GoogleIdentityPlatformConfig#quota_duration}
    */
    readonly quotaDuration?: string;
    /**
    * When this quota will take affect.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.78.0/docs/resources/google_identity_platform_config#start_time GoogleIdentityPlatformConfig#start_time}
    */
    readonly startTime?: string;
}
export declare function googleIdentityPlatformConfigQuotaSignUpQuotaConfigToTerraform(struct?: GoogleIdentityPlatformConfigQuotaSignUpQuotaConfigOutputReference | GoogleIdentityPlatformConfigQuotaSignUpQuotaConfig): any;
export declare class GoogleIdentityPlatformConfigQuotaSignUpQuotaConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleIdentityPlatformConfigQuotaSignUpQuotaConfig | undefined;
    set internalValue(value: GoogleIdentityPlatformConfigQuotaSignUpQuotaConfig | undefined);
    private _quota?;
    get quota(): number;
    set quota(value: number);
    resetQuota(): void;
    get quotaInput(): number | undefined;
    private _quotaDuration?;
    get quotaDuration(): string;
    set quotaDuration(value: string);
    resetQuotaDuration(): void;
    get quotaDurationInput(): string | undefined;
    private _startTime?;
    get startTime(): string;
    set startTime(value: string);
    resetStartTime(): void;
    get startTimeInput(): string | undefined;
}
export interface GoogleIdentityPlatformConfigQuota {
    /**
    * sign_up_quota_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.78.0/docs/resources/google_identity_platform_config#sign_up_quota_config GoogleIdentityPlatformConfig#sign_up_quota_config}
    */
    readonly signUpQuotaConfig?: GoogleIdentityPlatformConfigQuotaSignUpQuotaConfig;
}
export declare function googleIdentityPlatformConfigQuotaToTerraform(struct?: GoogleIdentityPlatformConfigQuotaOutputReference | GoogleIdentityPlatformConfigQuota): any;
export declare class GoogleIdentityPlatformConfigQuotaOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleIdentityPlatformConfigQuota | undefined;
    set internalValue(value: GoogleIdentityPlatformConfigQuota | undefined);
    private _signUpQuotaConfig;
    get signUpQuotaConfig(): GoogleIdentityPlatformConfigQuotaSignUpQuotaConfigOutputReference;
    putSignUpQuotaConfig(value: GoogleIdentityPlatformConfigQuotaSignUpQuotaConfig): void;
    resetSignUpQuotaConfig(): void;
    get signUpQuotaConfigInput(): GoogleIdentityPlatformConfigQuotaSignUpQuotaConfig | undefined;
}
export interface GoogleIdentityPlatformConfigTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.78.0/docs/resources/google_identity_platform_config#create GoogleIdentityPlatformConfig#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.78.0/docs/resources/google_identity_platform_config#delete GoogleIdentityPlatformConfig#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.78.0/docs/resources/google_identity_platform_config#update GoogleIdentityPlatformConfig#update}
    */
    readonly update?: string;
}
export declare function googleIdentityPlatformConfigTimeoutsToTerraform(struct?: GoogleIdentityPlatformConfigTimeouts | cdktf.IResolvable): any;
export declare class GoogleIdentityPlatformConfigTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleIdentityPlatformConfigTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleIdentityPlatformConfigTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.78.0/docs/resources/google_identity_platform_config google_identity_platform_config}
*/
export declare class GoogleIdentityPlatformConfig extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_identity_platform_config";
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.78.0/docs/resources/google_identity_platform_config google_identity_platform_config} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleIdentityPlatformConfigConfig = {}
    */
    constructor(scope: Construct, id: string, config?: GoogleIdentityPlatformConfigConfig);
    private _authorizedDomains?;
    get authorizedDomains(): string[];
    set authorizedDomains(value: string[]);
    resetAuthorizedDomains(): void;
    get authorizedDomainsInput(): string[] | undefined;
    private _autodeleteAnonymousUsers?;
    get autodeleteAnonymousUsers(): boolean | cdktf.IResolvable;
    set autodeleteAnonymousUsers(value: boolean | cdktf.IResolvable);
    resetAutodeleteAnonymousUsers(): void;
    get autodeleteAnonymousUsersInput(): boolean | cdktf.IResolvable | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get name(): string;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _blockingFunctions;
    get blockingFunctions(): GoogleIdentityPlatformConfigBlockingFunctionsOutputReference;
    putBlockingFunctions(value: GoogleIdentityPlatformConfigBlockingFunctions): void;
    resetBlockingFunctions(): void;
    get blockingFunctionsInput(): GoogleIdentityPlatformConfigBlockingFunctions | undefined;
    private _quota;
    get quota(): GoogleIdentityPlatformConfigQuotaOutputReference;
    putQuota(value: GoogleIdentityPlatformConfigQuota): void;
    resetQuota(): void;
    get quotaInput(): GoogleIdentityPlatformConfigQuota | undefined;
    private _timeouts;
    get timeouts(): GoogleIdentityPlatformConfigTimeoutsOutputReference;
    putTimeouts(value: GoogleIdentityPlatformConfigTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleIdentityPlatformConfigTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
